<nav>
    <a href="index.php">Strona główna</a> |
    <a href="oferta.php">Oferta</a> |
    <a href="rezerwacja.php">Rezerwacja</a> |
    <a href="kontakt.php">Kontakt</a> |
    <a class="admin-link" href="admin_rezerwacje.php">Admin</a>
</nav>
