
<?php include("includes/header.php"); ?>
<?php include("includes/nav.php"); ?>

<main>
    <h1>Kontakt</h1>

    <div class="kontakt-box">
        <h2>Myjnia Samochodowa Błysk</h2>

        <p><strong>Adres:</strong><br>
        ul. Rolna 12<br>
        96-300 Żyrardów</p>

        <p><strong>Telefon:</strong><br>
        123 456 789</p>

        <p><strong>Email:</strong><br>
        myjnia@hps.ovh</p>

        <p><strong>Godziny otwarcia:</strong><br>
        Pon–Pt: 8:00 – 18:00<br>
        Sobota: 9:00 – 15:00<br>
        Niedziela: zamknięte</p>
    </div>
</main>

<?php include("includes/footer.php"); ?>
