<!-- projekt dostepny tez pod https://myjnia.hps.ovh -->
<?php
$host = "localhost";
$user = "ptysiu";
$pass = "Papiesz2137";
$db = "myjnia";

$conn = mysqli_connect($host, $user, $pass, $db);

if (!$conn) {
    die("Błąd połączenia: " . mysqli_connect_error());
}
?>