<!DOCTYPE html>
<html lang="pl">
<head>
    <meta charset="UTF-8">
    <title>Myjnia Samochodowa</title>
    <link rel="stylesheet" href="style.css">
    <link rel="icon" href="includes/chatgpt_generated_icon.ico" type="image/x-icon">
</head>
<body>

<header class="site-header">
    <div class="header-container">
        <div class="logo">
            Myjnia <span>Błysk</span>
        </div>
</header>
<main>



